==> ninix-aya_4.0.1.orig.tar.gz: ninix-aya-4.0.1/lib/ninix/alias.py <==
# -*- coding: utf-8 -*-
#
#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
#  Copyright (C) 2004-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#

import __builtin__
import sys

import ninix.config

def print_error(message):
    sys.stderr.write(''.join((message, '\n')))

def fatal(error):
    print_error('alias.py: %s' % str(error))
    return ninix.config.null_config()

def open(path):
    f = __builtin__.open(path)
    buf = []
    for line in f:
        line = line.strip()
        if not line:
            continue
        buf.append(line)
    f.close()
    return new_alias(buf)

def new_alias(buf):
    dic = ninix.config.Config()
    i, j = 0, len(buf)
    while i < j:
        line = buf[i]
        i += 1
        if line in ['sakura.surface.alias', 'kero.surface.alias']:
            name = line
            table = {}
            try:
                while 1:
                    if i < j:
                        line = buf[i]
                        i += 1
                    else:
                        raise ValueError, 'unexpedted end of file'
                    line = line.replace('\x81\x40', '').strip()
                    if not line:
                        continue
                    elif line == '{':
                        break
                    raise ValueError, 'open brace not found'
                while 1:
                    if i < j:
                        line = buf[i]
                        i += 1
                    else:
                        raise ValueError, 'unexpected end of file'
                    line = line.replace('\x81\x40', '').strip()
                    if not line:
                        continue
                    elif line == '}':
                        break
                    line = line.split(',', 1)
                    if len(line) == 2:
                        key, values = [s.strip() for s in line]
                    else:
                        raise ValueError, 'malformed line found'
                    if values and \
                       values.startswith('[') and values.endswith(']'):
                        table[key] = []
                        for value in values[1:-1].split(','):
                            try:
                                value = str(int(value))
                            except ValueError:
                                pass
                            table[key].append(value)
                    else:
                        raise ValueError, 'malformed line found'
            except ValueError, error:
                return fatal(error)
            dic[name] = table
        else:
            line = line.split(',', 1)
            if len(line) == 2:
                key, value = [s.strip() for s in line]
            else:
                return fatal('malformed line found')
            if key == 'makoto':
                if value and \
                   value.startswith('[') and value.endswith(']'):
                    value = value[1:-1].split(',')
                else:
                    value = [value]
            dic[key] = value
    return dic

# test
if __name__ == '__main__':
    print open(sys.argv[1])

==> ninix-aya_4.0.7.orig.tar.gz: ninix-aya-4.0.7/lib/ninix/alias.py <==
# -*- coding: utf-8 -*-
#
#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
#  Copyright (C) 2004-2010 by Shyouzou Sugitani <shy@users.sourceforge.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#

import sys

import ninix.config

def print_error(message):
    sys.stderr.write(''.join((message, '\n')))

def fatal(error):
    print_error('alias.py: %s' % str(error))
    return ninix.config.null_config()

def create_from_file(path):
    f = open(path)
    buf = []
    for line in f:
        line = line.strip()
        if not line:
            continue
        buf.append(line)
    f.close()
    return create_from_buffer(buf)

def create_from_buffer(buf):
    dic = ninix.config.Config()
    i, j = 0, len(buf)
    while i < j:
        line = buf[i]
        i += 1
        if line in ['sakura.surface.alias', 'kero.surface.alias']:
            name = line
            table = {}
            try:
                while 1:
                    if i < j:
                        line = buf[i]
                        i += 1
                    else:
                        raise ValueError, 'unexpedted end of file'
                    line = line.replace('\x81\x40', '').strip()
                    if not line:
                        continue
                    elif line == '{':
                        break
                    raise ValueError, 'open brace not found'
                while 1:
                    if i < j:
                        line = buf[i]
                        i += 1
                    else:
                        raise ValueError, 'unexpected end of file'
                    line = line.replace('\x81\x40', '').strip()
                    if not line:
                        continue
                    elif line == '}':
                        break
                    line = line.split(',', 1)
                    if len(line) == 2:
                        key, values = [s.strip() for s in line]
                    else:
                        raise ValueError, 'malformed line found'
                    if values and \
                       values.startswith('[') and values.endswith(']'):
                        table[key] = []
                        for value in values[1:-1].split(','):
                            try:
                                value = str(int(value))
                            except ValueError:
                                pass
                            table[key].append(value)
                    else:
                        raise ValueError, 'malformed line found'
            except ValueError, error:
                return fatal(error)
            dic[name] = table
        else:
            line = line.split(',', 1)
            if len(line) == 2:
                key, value = [s.strip() for s in line]
            else:
                return fatal('malformed line found')
            if key == 'makoto':
                if value and \
                   value.startswith('[') and value.endswith(']'):
                    value = value[1:-1].split(',')
                else:
                    value = [value]
            dic[key] = value
    return dic

# test
if __name__ == '__main__':
    print create_from_file(sys.argv[1])
